.. :changelog:

History
=======

0.1.3 (2015-08-25)
------------------

BugFix

* added MANIFEST.in (fix install problem)


0.1.2 (2015-08-21)
------------------

BugFix

* Correct wrong api url


0.1.1 (2015-08-21)
------------------

* Add module logger
* Add class logger
* Functions throw AirgramException on failure


0.1.0 (2015-07-30)
------------------

* First release on PyPI.